// Track Map API

/* global variables for track map */
// min and max values of coordinates
var minX, maxX, minY, maxY = 0;
// scale factor
var sf = 1;
// shift in x and y direction
var xShift, yShift = 0;
var initDriverTrackPosition = true;
var sectorColors = ["green","yellow","red","blue","pink","orange","lightgreen","lightred","lightblue"];

/*
 * drawLine function
 * parameter canvasID (string), the element id of the canvas elementFromPoint
 * parameter x (float), x coordinate
 * parameter y (float), y coordinate
 * parameter lineWidth (int), defines the width of the line
 * parameter strokeStyle (string), defines the color of the line
 *
 * starts with a new line if initDriverTrackPosition=true else line will be appended
 */
function drawLine(canvasID,x,y,lineWidth,strokeStyle)
{
	console.log('drawLine');
	var canvas=document.getElementById(canvasID);
	var ctx=canvas.getContext("2d");
	ctx.lineWidth = lineWidth;
	ctx.strokeStyle = strokeStyle;	
	if(initDriverTrackPosition){
		ctx.beginPath();
		ctx.moveTo(((x/sf)+xShift),((y/sf)+yShift));
		initDriverTrackPosition = false;
	}
	else{
		ctx.lineTo(((x/sf)+xShift),((y/sf)+yShift));
	}
	ctx.stroke();
}

/*
 * drawTrackMap function
 * parameter canvasID (string), the element id of the canvas element
 * parameter points (array), an array with points
 * parameter lineWidth (int), defines the width of the line
 * parameter strokeStyle (string), defines the color of the line
 *
 * draws a complete track map for the given points
 */
function drawTrackMap(canvasID, points, lineWidth, strokeStyle)
{
	console.log('drawTrackMap');
	var canvas=document.getElementById(canvasID);
	var ctx=canvas.getContext("2d");
	ctx.lineWidth = lineWidth;
	ctx.strokeStyle = strokeStyle;
	ctx.beginPath();			
	for(i=0;i<points.length;i++){
		//console.log(i+' - ' + points[i].x + ' - ' + points[i].z);
		if(i==0) ctx.moveTo(((points[i].x/sf)+xShift),((points[i].z/sf)+yShift));
		else ctx.lineTo(((points[i].x/sf)+xShift),((points[i].z/sf)+yShift));
	}
	ctx.stroke();
	//ctx.closePath();
	initDriverTrackPosition = true;
}

/*
 * drawInitalTrackMap function
 * parameter canvasID (string), the element id of the canvas element
 * parameter points (array), an array with points
 * parameter marginX (int), margin in x direction
 * parameter marginY (int), margin in y direction
 * parameter lineWidth (int), defines the width of the line
 * parameter strokeStyle (string), defines the color of the line
 *
 * draws a full track map for the given points
 */
function drawInitalTrackMap(canvasID, points, marginX, marginY, lineWidth, strokeStyle)
{
	console.log('drawInitalTrackMap');
	for(i = 0; i < points.length; i++)
	{
		if(i==0){
			minX = points[i].x;
			maxX = points[i].x;
			minY = points[i].z;
			maxY = points[i].z;
		}
		else{
			if(points[i].x < minX) minX = points[i].x;
			if(points[i].x > maxX) maxX = points[i].x;
			if(points[i].z < minY) minY = points[i].z;
			if(points[i].z > maxY) maxY = points[i].z;
		}
	}
	sf = calculateScaleFactor(canvasID,minX,maxX,minY,maxY,marginX,marginY);
	xShift = calculateAxisShift(minX, sf, marginX);
	yShift = calculateAxisShift(minY, sf, marginY);
	drawTrackMap(canvasID, points, lineWidth, strokeStyle);
}

/*
 * drawInitalTrackMapSectors function
 * parameter canvasID (string), the element id of the canvas element
 * parameter points (array), an array where each item consists of a point and sector
 * parameter marginX (int), margin in x direction
 * parameter marginY (int), margin in y direction
 * parameter lineWidth (int), defines the width of the line
 * parameter strokeStyles (array), defines the colors of each sector
 *
 * draws a full track map for the given points with different colored sectors
 */
function drawInitalTrackMapSectors(canvasID, points, marginX, marginY, lineWidth, strokeStyles)
{
	console.log('drawInitalTrackMapSectors');
	var sectorPoints = new Array();
	for(i = 0; i < points.length; i++)
	{
		if(i==0){
			minX = points[i].x;
			maxX = points[i].x;
			minY = points[i].z;
			maxY = points[i].z;
		}
		else{
			if(points[i].x < minX) minX = points[i].x;
			if(points[i].x > maxX) maxX = points[i].x;
			if(points[i].z < minY) minY = points[i].z;
			if(points[i].z > maxY) maxY = points[i].z;
		}
		
		if(points[i].s == sectorPoints.length){
			console.log("new Sector");
			sectorPoints[points[i].s] = new Array();
			if(points[i].s != 0) sectorPoints[points[i].s].push(points[i-1]);
		}
		else if(points[i].s == sectorPoints.length-1) sectorPoints[points[i].s].push(points[i]);
	}
	sf = calculateScaleFactor(canvasID,minX,maxX,minY,maxY,marginX,marginY);
	xShift = calculateAxisShift(minX, sf, marginX);
	yShift = calculateAxisShift(minY, sf, marginY);
	if(sectorPoints.length > strokeStyles.length) strokeStyles = sectorColors;
	
	var c = 0;
	sectorPoints.forEach(function(item){
		console.log('Draw Sector');
		drawTrackMap(canvasID, item, lineWidth, strokeStyles[c]);
		c++;
	});
}

/*
 * clearTrackMap function
 * parameter canvasID (string), the element id of the canvas element
 *
 * clears the canvas element, removes track map
 */
function clearTrackMap(canvasID)
{
	console.log('clearTrackMap');
	var canvas=document.getElementById(canvasID);
	var ctx=canvas.getContext("2d");
	ctx.clearRect(0, 0, canvas.width, canvas.height);
	ctx.beginPath();
}

// Helper functions

function calculateScaleFactor(canvasID, minX, maxX, minY, maxY, marginX, marginY)
{
	console.log('CalculateScaleFactor');
	var width = document.getElementById(canvasID).width-marginX;
	var height = document.getElementById(canvasID).height-marginY;
	var sfX = (maxX-minX) <= width ? 1 : (maxX-minX)/width;
	var sfY = (maxY-minY) <= height ? 1 : (maxY-minY)/height;
	if(sfX > sfY) return sfX;
	else return sfY;
	
}

function calculateAxisShift(min, scaleFactor, margin){
	console.log('CalculateAxisShift');
	return ((min/scaleFactor)+margin)*(-1);
}