// Utils API

/*
 * SecondsToGapTimeString function
 * parameter seconds (float)
 *
 * returns a formatted string representation for the gap
 * eg. 60.750 seconds ==> +1:00.750
 * eg. -60.750 seconds ==> -1:00.750 
 */
function SecondsToGapTimeString(seconds) {		
	var neg = false;
	if(seconds==0) return "0:00.000";
	if(seconds < 0){
		neg = true;
		seconds = (seconds * -1)
	}
	seconds = seconds.toFixed(3);
	var min = ~~(seconds/60);
	var sec = ~~(seconds-(min*60));
	var ms = seconds.split('.')[1];
	return (neg ? '-' : '+')+(min==0 ? '' : min+':')+(sec < 10 ? 0 : '')+sec+'.'+ms;
}

/*
 * SecondsToTimeString function
 * parameter seconds (float)
 *
 * returns a formatted string representation for a lap time
 * eg. 60.750 seconds ==> 1:00.750 
 */
function SecondsToTimeString(seconds) {
	seconds = seconds.toFixed(3) + '';
	var min = ~~(seconds/60);
	var sec = ~~(seconds-(min*60))
	var ms = seconds.split('.')[1];
	return min+':'+(sec < 10 ? 0 : '')+sec+'.'+(!ms?'000':ms);
}

/*
 * SecondsToTime function
 * parameter seconds (float)
 *
 * returns a formatted string representation for the time
 * eg. 3671.5 seconds ==> 1:01.11 
 */
function SecondsToTime(seconds) {
	seconds = seconds.toFixed(0) + '';
	var min = ~~(seconds/60);
	var hour = ~~(min/60);
	if(hour < 1) hour = 0;
	else min = min - (hour.toFixed(0)*60);
	var sec = ~~(seconds-(min*60))
	return (hour==0 ? '' : (hour + ':')) + (min < 10 ? 0 : '')+min+'.'+(sec < 10 ? 0 : '')+sec;
}

/*
 * GetSessionString function
 * parameter session_id (int)
 *
 * returns the session as string
 * eg. 3 ==> Practice 3 
 */
function GetSessionString(session_id) {
	var result = "";
	switch(session_id){
		case -1: result = "unknown"; break;
		case 0: result = "Practice"; break;
		case 1: result = "Practice 1"; break;
		case 2: result = "Practice 2"; break;
		case 3: result = "Practice 3"; break;
		case 4: result = "Practice 4"; break;
		case 5: result = "Qualifying"; break;
		case 6: result = "Qualifying 1"; break;
		case 7: result = "Qualifying 2"; break;
		case 8: result = "Warmup"; break;
		case 9: result = "Race"; break;
		case 10: result = "Race 1"; break;
		case 11: result = "Race 2"; break;
		case 12: result = "Results"; break;
		case 13: result = "Hotlap"; break;
		case 14: result = "Time Attack"; break;
		case 15: result = "Drift"; break;
		case 16: result = "Drag"; break;		
		default: result = "unknown"; break;
	}
	return result;
}

/*
 * GetSimString function
 * parameter sim_id (int)
 *
 * returns the simulation as string
 * eg. 4 ==> RaceRoom Racing Experience 
 */
function GetSimString(sim_id) {
	var result = "";
	switch(Sim){
		case 0: result = "Assetto Corsa"; break;
		case 1: result = "Race 07"; break;
		case 2: result = "GTR 2"; break;
		case 3: result = "GT Legends"; break;
		case 4: result = "RaceRoom Racing Experience"; break;
		default: result = "Unkown Game"; break;
	}
	return result;
}

/* variables for tyre */
var sr_temp_tyre = "";
var sr_temp_upper = 0;
var sr_temp_lower = 0;

/*
 * SetTyreTemperatureColor function
 * parameter id (string), id of html element
 * parameter temp (float), temperature value
 *
 * styles the html elements background color depending on temperature of tyre and tyre type 
 */
function SetTyreTemperatureColor(id, temp) {
	if(!(sr_temp_tyre == Tyre)){
		sr_temp_tyre = Tyre;
		if(Sim == 0){
			// Assetto Corsa
			switch(Group){
				case "street":
					switch(Tyre)
					{
						case "Street":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Street 90s":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Street90S":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Semislicks":
							sr_temp_upper = TempUnit==0 ? 95 : 203;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
					}
					break;
				case "classic":
					switch(Tyre)
					{
						case "Slicks Soft DTM90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slicks Soft Gr.A":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slicks Medium DTM90s":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Medium Gr.A":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Hard DTM90s":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Slicks Hard Gr.A":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Vintage":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Performance":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Street":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Street 90s":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Street90S":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Semislicks":
							sr_temp_upper = TempUnit==0 ? 95 : 203;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Pirelli Cinturato":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Soft 90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Medium 90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Hard 90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Soft Slicks 90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Medium Slicks 90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Hard Slicks 90s":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "S.Slick F Street R":
							sr_temp_upper = TempUnit==0 ? 95 : 203;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Street F S90 R":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Junkyard Tyres":
							sr_temp_upper = TempUnit==0 ? 80 : 176;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
					}
					break;
				case "gt":
					switch(Tyre)
					{
						case "Slick Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slick Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slick Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Slicks Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Medium":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Hard":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Semislicks":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "TopGear Record":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Intermediate Race":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Hypercar Street Tyres":
							sr_temp_upper = TempUnit==0 ? 95 : 203;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Sports Street Tyres":
							sr_temp_upper = TempUnit==0 ? 85 : 185;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "S9H":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
					}
					break;
				case "gt2":
					switch(Tyre)
					{
						case "Slick SuperSoft":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Slick Soft":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Slick Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 85 : 185;
							break;
						case "Slick Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slick SuperHard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "SuperSoft":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Soft":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 85 : 185;
							break;
						case "Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Endurance":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
					}
					break;
				case "gt3":
					switch(Tyre)
					{
						case "Slick Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slick Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slick Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
					}
					break;
				case "f1_classic":
					switch(Tyre)
					{
						case "F1 1967":
							sr_temp_upper = TempUnit==0 ? 90 : 194;
							sr_temp_lower = TempUnit==0 ? 50 : 122;
							break;
						case "Soft 70F1":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Hard 70F1":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Qualifying":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 85 : 185;
							break;
						case "Soft 86F1":
							sr_temp_upper = TempUnit==0 ? 125 : 257;
							sr_temp_lower = TempUnit==0 ? 105 : 221;
							break;
						case "Medium 86F1":
							sr_temp_upper = TempUnit==0 ? 115 : 239;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Hard 86F1":
							sr_temp_upper = TempUnit==0 ? 135 : 275;
							sr_temp_lower = TempUnit==0 ? 110 : 230;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
					}
					break;
				case "f1":
					switch(Tyre)
					{
						case "Slick SuperSoft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 85 : 185;
							break;
						case "Slick Soft":
							sr_temp_upper = TempUnit==0 ? 125 : 257;
							sr_temp_lower = TempUnit==0 ? 105 : 221;
							break;
						case "Slick Medium":
							sr_temp_upper = TempUnit==0 ? 115 : 239;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Slick Hard":
							sr_temp_upper = TempUnit==0 ? 135 : 275;
							sr_temp_lower = TempUnit==0 ? 110 : 230;
							break;
						case "SuperSoft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 85 : 185;
							break;
						case "Soft":
							sr_temp_upper = TempUnit==0 ? 125 : 257;
							sr_temp_lower = TempUnit==0 ? 105 : 221;
							break;
						case "Medium":
							sr_temp_upper = TempUnit==0 ? 115 : 239;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						case "Hard":
							sr_temp_upper = TempUnit==0 ? 135 : 275;
							sr_temp_lower = TempUnit==0 ? 110 : 230;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 135 : 275;
							sr_temp_lower = TempUnit==0 ? 85 : 185;
							break;
					}
				break;
				case "formula":
					switch(Tyre)
					{
						case "Slicks Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slicks Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slicks Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Slick Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slick Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slick Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
						case "Slick Exos":
							sr_temp_upper = TempUnit==0 ? 120 : 248;
							sr_temp_lower = TempUnit==0 ? 90 : 194;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 120 : 248;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;
					}
					break;
				case "cup":
					switch(Tyre)
					{
						case "Semislicks":
							sr_temp_upper = TempUnit==0 ? 95 : 203;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Dunlop Slick":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Pirelli P-ZERO":
							sr_temp_upper = TempUnit==0 ? 95 : 203;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "MICHELIN":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slick Soft":
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 80 : 176;
							break;
						case "Slick Medium":
							sr_temp_upper = TempUnit==0 ? 105 : 221;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
						case "Slick Hard":
							sr_temp_upper = TempUnit==0 ? 100 : 212;
							sr_temp_lower = TempUnit==0 ? 70 : 158;
							break;	
						default:
							sr_temp_upper = TempUnit==0 ? 110 : 230;
							sr_temp_lower = TempUnit==0 ? 75 : 167;
							break;
					}
					break;
				case "kart":
					switch(Tyre)
					{
						case "Slicks Soft":
							sr_temp_upper = TempUnit==0 ? 75 : 167;
							sr_temp_lower = TempUnit==0 ? 60 : 140;
							break;
						default:
							sr_temp_upper = TempUnit==0 ? 75 : 167;
							sr_temp_lower = TempUnit==0 ? 60 : 140;
							break;
					}
					break;
				default:
					sr_temp_upper = TempUnit==0 ? 120 : 248;
					sr_temp_lower = TempUnit==0 ? 70 : 158;
					break;
			}
		}
		else if(Sim == 1){
			// Race07
			sr_temp_upper = TempUnit==0 ? 90 : 194;
			sr_temp_lower = TempUnit==0 ? 80 : 176;
		}
		else {
			// GTR2, GTL & R3E
			sr_temp_upper = TempUnit==0 ? 100 : 212;
			sr_temp_lower = TempUnit==0 ? 80 : 176;
		}
	}
	if(temp < sr_temp_lower){
		// blue
		document.getElementById(id).style.background = 'blue';
	}
	else if(temp > sr_temp_upper){
		// red
		document.getElementById(id).style.background = 'red';
	}
	else {
		// green
		document.getElementById(id).style.background = 'green';
	}
	return;
}